==> stylish-haskell-0.12.2.0-80-x86_64.pkg.tar.zst: usr/share/haskell/register/stylish-haskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 stylish-haskell
version:              0.12.2.0
visibility:           public
id:                   stylish-haskell-0.12.2.0-1rGKWXr0jnBsWc3vUHxaY
key:                  stylish-haskell-0.12.2.0-1rGKWXr0jnBsWc3vUHxaY
license:              BSD-3-Clause
copyright:            2012 Jasper Van der Jeugt
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt <m@jaspervdj.be>
homepage:             https://github.com/jaspervdj/stylish-haskell
synopsis:             Haskell code prettifier
description:
    A Haskell code prettifier. For more information, see:

    <https://github.com/jaspervdj/stylish-haskell/blob/master/README.markdown>

category:             Language
abi:                  0f294a2cf48b76ed33f504691034faf9
exposed:              True
exposed-modules:
    Language.Haskell.Stylish Language.Haskell.Stylish.GHC
    Language.Haskell.Stylish.Module Language.Haskell.Stylish.Printer
    Language.Haskell.Stylish.Step.Data
    Language.Haskell.Stylish.Step.Imports
    Language.Haskell.Stylish.Step.LanguagePragmas
    Language.Haskell.Stylish.Step.ModuleHeader
    Language.Haskell.Stylish.Step.SimpleAlign
    Language.Haskell.Stylish.Step.Squash
    Language.Haskell.Stylish.Step.Tabs
    Language.Haskell.Stylish.Step.TrailingWhitespace
    Language.Haskell.Stylish.Step.UnicodeSyntax

hidden-modules:
    Language.Haskell.Stylish.Align Language.Haskell.Stylish.Block
    Language.Haskell.Stylish.Config
    Language.Haskell.Stylish.Config.Cabal
    Language.Haskell.Stylish.Config.Internal
    Language.Haskell.Stylish.Editor Language.Haskell.Stylish.Ordering
    Language.Haskell.Stylish.Parse Language.Haskell.Stylish.Step
    Language.Haskell.Stylish.Util Language.Haskell.Stylish.Verbose
    Paths_stylish_haskell

import-dirs:          /usr/lib/ghc-9.0.1/site-local/stylish-haskell-0.12.2.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/stylish-haskell-0.12.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stylish-haskell
hs-libraries:         HSstylish-haskell-0.12.2.0-1rGKWXr0jnBsWc3vUHxaY
depends:
    Cabal-3.4.0.0 HsYAML-0.2.1.0-L79VA3bXKcn8qur4XqdklC
    HsYAML-aeson-0.2.0.0-32xhnLbATgn3dAjuorrURu
    aeson-1.5.6.0-KLnW8ZNssug7g6SUFAYcU2 base-4.15.0.0
    bytestring-0.10.12.1 containers-0.6.4.1 directory-1.3.6.1
    file-embed-0.0.14.0-DpVDNlFaM0M9fTuZiTfuRf filepath-1.4.2.1
    ghc-lib-parser-8.10.5.20210606-Cd7ZmKI18GmFZVpU2ZyZVZ mtl-2.2.2
    syb-0.7.2.1-3ORM9hCNu8V5barlF73jrL text-1.2.4.1

haddock-interfaces:   /usr/share/doc/stylish-haskell/html/stylish-haskell.haddock
haddock-html:         /usr/share/doc/stylish-haskell/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> stylish-haskell-0.12.2.0-81-x86_64.pkg.tar.zst: usr/share/haskell/register/stylish-haskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 stylish-haskell
version:              0.12.2.0
visibility:           public
id:                   stylish-haskell-0.12.2.0-LiaNUwMVKrp4YNqgQRvSOi
key:                  stylish-haskell-0.12.2.0-LiaNUwMVKrp4YNqgQRvSOi
license:              BSD-3-Clause
copyright:            2012 Jasper Van der Jeugt
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt <m@jaspervdj.be>
homepage:             https://github.com/jaspervdj/stylish-haskell
synopsis:             Haskell code prettifier
description:
    A Haskell code prettifier. For more information, see:

    <https://github.com/jaspervdj/stylish-haskell/blob/master/README.markdown>

category:             Language
abi:                  823c8403b418bb8f70e65cf92d4a1a1a
exposed:              True
exposed-modules:
    Language.Haskell.Stylish Language.Haskell.Stylish.GHC
    Language.Haskell.Stylish.Module Language.Haskell.Stylish.Printer
    Language.Haskell.Stylish.Step.Data
    Language.Haskell.Stylish.Step.Imports
    Language.Haskell.Stylish.Step.LanguagePragmas
    Language.Haskell.Stylish.Step.ModuleHeader
    Language.Haskell.Stylish.Step.SimpleAlign
    Language.Haskell.Stylish.Step.Squash
    Language.Haskell.Stylish.Step.Tabs
    Language.Haskell.Stylish.Step.TrailingWhitespace
    Language.Haskell.Stylish.Step.UnicodeSyntax

hidden-modules:
    Language.Haskell.Stylish.Align Language.Haskell.Stylish.Block
    Language.Haskell.Stylish.Config
    Language.Haskell.Stylish.Config.Cabal
    Language.Haskell.Stylish.Config.Internal
    Language.Haskell.Stylish.Editor Language.Haskell.Stylish.Ordering
    Language.Haskell.Stylish.Parse Language.Haskell.Stylish.Step
    Language.Haskell.Stylish.Util Language.Haskell.Stylish.Verbose
    Paths_stylish_haskell

import-dirs:          /usr/lib/ghc-9.0.1/site-local/stylish-haskell-0.12.2.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/stylish-haskell-0.12.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stylish-haskell
hs-libraries:         HSstylish-haskell-0.12.2.0-LiaNUwMVKrp4YNqgQRvSOi
depends:
    Cabal-3.4.0.0 HsYAML-0.2.1.0-L79VA3bXKcn8qur4XqdklC
    HsYAML-aeson-0.2.0.0-54fA0fuHX6S6J8b26V6g9g
    aeson-1.5.6.0-nrMp0b6teF7D3JqNhCf9o base-4.15.0.0
    bytestring-0.10.12.1 containers-0.6.4.1 directory-1.3.6.1
    file-embed-0.0.14.0-DpVDNlFaM0M9fTuZiTfuRf filepath-1.4.2.1
    ghc-lib-parser-8.10.5.20210606-Cd7ZmKI18GmFZVpU2ZyZVZ mtl-2.2.2
    syb-0.7.2.1-3ORM9hCNu8V5barlF73jrL text-1.2.4.1

haddock-interfaces:   /usr/share/doc/stylish-haskell/html/stylish-haskell.haddock
haddock-html:         /usr/share/doc/stylish-haskell/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
